@@ -6,23 +6,21 @@
 
 
 ## Auxiliary functions to check the given class of an objet
-isPLNnetworkfamily <- function(Robject) {inherits(Robject, "PLNnetworkfamily")}
+isNetworkfamily <- function(Robject) {inherits(Robject, "Networkfamily")}
 
-#' Display various outputs (goodness-of-fit criteria, robustness, diagnostic) associated with a collection of PLNnetwork fits (a [`PLNnetworkfamily`])
-#'
-#' @name plot.PLNnetworkfamily
+#' Display various outputs (goodness-of-fit criteria, robustness, diagnostic) associated with a collection of network fits (either [`PLNnetworkfamily`] or [`ZIPLNnetworkfamily`])
 #'
 #' @inheritParams plot.PLNfamily
 #' @inherit plot.PLNfamily return details
 #'
-#' @param x an R6 object with class [`PLNnetworkfamily`]
+#' @param x an R6 object with class [`PLNnetworkfamily`] or [`ZIPLNnetworkfamily`]
 #' @param type a character, either "criteria", "stability" or "diagnostic" for the type of plot.
-#' @param criteria vector of characters. The criteria to plot in c("loglik", "BIC", "ICL", "R_squared", "EBIC", "pen_loglik").
-#' Default is  c("loglik", "pen_loglik", "BIC", "EBIC"). Only relevant when `type = "criteria"`.
+#' @param criteria Vector of criteria to plot, to be selected among "loglik" (log-likelihood),
+#' "BIC", "ICL", "R_squared", "EBIC" and "pen_loglik" (penalized log-likelihood).
+#' Default is  c("loglik", "pen_loglik", "BIC", "EBIC"). Only used when `type = "criteria"`.
 #' @param log.x logical: should the x-axis be represented in log-scale? Default is `TRUE`.
 #' @param stability scalar: the targeted level of stability in stability plot. Default is .9.
 #'
-#'
 #' @examples
 #' data(trichoptera)
 #' trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
@@ -30,18 +28,17 @@ isPLNnetworkfamily <- function(Robject) {inherits(Robject, "PLNnetworkfamily")}
 #' \dontrun{
 #' plot(fits)
 #' }
-#' @return Produces either a diagnostic plot (with \code{type = 'diagnostic'}), a stability plot
-#' (with \code{type = 'stability'}) or the evolution of the criteria of the different models considered
-#' (with \code{type = 'criteria'}, the default).
+#' @return Produces either a diagnostic plot (with `type = 'diagnostic'`), a stability plot
+#' (with `type = 'stability'`) or the evolution of the criteria of the different models considered
+#' (with `type = 'criteria'`, the default).
 #' @export
-plot.PLNnetworkfamily <-
-  function(x,
+plot.Networkfamily <- function(x,
            type     = c("criteria", "stability", "diagnostic"),
            criteria = c("loglik", "pen_loglik", "BIC", "EBIC"),
            reverse = FALSE,
            log.x    = TRUE,
            stability = 0.9, ...) {
-  stopifnot(isPLNnetworkfamily(x))
+  stopifnot(isNetworkfamily(x))
   type <- match.arg(type)
   if (type == "criteria")
     p <- x$plot(criteria, reverse)
@@ -53,27 +50,50 @@ plot.PLNnetworkfamily <-
   p
 }
 
-#' @describeIn getModel Model extraction for [`PLNnetworkfamily`]
+#' @describeIn plot.Networkfamily Display various outputs associated with a collection of network fits
 #' @export
-getModel.PLNnetworkfamily <- function(Robject, var, index = NULL) {
-  stopifnot(isPLNnetworkfamily(Robject))
+plot.PLNnetworkfamily <- plot.Networkfamily
+
+#' @describeIn plot.Networkfamily Display various outputs associated with a collection of network fits
+#' @export
+plot.ZIPLNnetworkfamily <- plot.Networkfamily
+
+#' @describeIn getModel Model extraction for [`PLNnetworkfamily`] or [`ZIPLNnetworkfamily`]
+#' @export
+getModel.Networkfamily <- function(Robject, var, index = NULL) {
+  stopifnot(isNetworkfamily(Robject))
   Robject$getModel(var, index)
 }
 
-#' @describeIn getBestModel Model extraction for [`PLNnetworkfamily`]
+#' @describeIn getModel Model extraction for [`PLNnetworkfamily`]
 #' @export
-getBestModel.PLNnetworkfamily <- function(Robject, crit = c("BIC", "EBIC", "StARS"), ...) {
-  stopifnot(isPLNnetworkfamily(Robject))
+getModel.PLNnetworkfamily <- getModel.Networkfamily
+
+#' @describeIn getModel Model extraction for [`ZIPLNnetworkfamily`]
+#' @export
+getModel.ZIPLNnetworkfamily <- getModel.Networkfamily
+
+#' @describeIn getBestModel Model extraction for [`PLNnetworkfamily`] or [`ZIPLNnetworkfamily`]
+#' @export
+getBestModel.Networkfamily <- function(Robject, crit = c("BIC", "EBIC", "StARS"), ...) {
+  stopifnot(isNetworkfamily(Robject))
   stability <- list(...)[["stability"]]
   if (is.null(stability)) stability <- 0.9
   Robject$getBestModel(match.arg(crit), stability)
 }
 
+#' @describeIn getBestModel Model extraction for [`PLNnetworkfamily`]
+#' @export
+getBestModel.PLNnetworkfamily <- getBestModel.Networkfamily
+
+#' @describeIn getBestModel Model extraction for [`ZIPLNnetworkfamily`]
+#' @export
+getBestModel.ZIPLNnetworkfamily <- getBestModel.Networkfamily
 
 #' Extract the regularization path of a PLNnetwork fit
 #'
 #' @name coefficient_path
-#' @param Robject an object with class [`PLNnetworkfamily`], i.e. an output from [PLNnetwork()]
+#' @param Robject an object with class [`Networkfamily`], i.e. an output from [PLNnetwork()]
 #' @param precision a logical, should the coefficients of the precision matrix Omega or the covariance matrix Sigma be sent back. Default is `TRUE`.
 #' @param corr a logical, should the correlation (partial in case  `precision = TRUE`) be sent back. Default is `TRUE`.
 #'
@@ -85,7 +105,7 @@ getBestModel.PLNnetworkfamily <- function(Robject, crit = c("BIC", "EBIC", "StAR
 #' head(coefficient_path(fits))
 #' @export
 coefficient_path <- function(Robject, precision = TRUE, corr = TRUE) {
-  stopifnot(isPLNnetworkfamily(Robject))
+  stopifnot(isNetworkfamily(Robject))
   Robject$coefficient_path(precision, corr)
 }
 
@@ -95,12 +115,12 @@ coefficient_path <- function(Robject, precision = TRUE, corr = TRUE) {
 #'
 #' @description This function computes the StARS stability criteria over a path of penalties. If a path has already been computed, the functions stops with a message unless `force = TRUE` has been specified.
 #'
-#' @param Robject an object with class [`PLNnetworkfamily`], i.e. an output from [PLNnetwork()]
-#' @param subsamples a list of vectors describing the subsamples. The number of vectors (or list length) determines th number of subsamples used in the stability selection. Automatically set to 20 subsamples with size \code{10*sqrt(n)} if \code{n >= 144} and \code{0.8*n} otherwise following Liu et al. (2010) recommendations.
-#' @param control a list controlling the main optimization process in each call to PLNnetwork. See [PLNnetwork()] for details.
+#' @param Robject an object with class [`PLNnetworkfamily`] or [`ZIPLNnetworkfamily`], i.e. an output from [PLNnetwork()] or [ZIPLNnetwork()]
+#' @param subsamples a list of vectors describing the subsamples. The number of vectors (or list length) determines th number of subsamples used in the stability selection. Automatically set to 20 subsamples with size `10*sqrt(n)` if `n >= 144` and `0.8*n` otherwise following Liu et al. (2010) recommendations.
+#' @param control a list controlling the main optimization process in each call to [PLNnetwork()] or [ZIPLNnetwork()]. See [PLN_param()] or [ZIPLN_param()] for details.
 #' @param force force computation of the stability path, even if a previous one has been detected.
 #'
-#' @return the list of subsamples. The estimated probabilities of selection of the edges are stored in the fields `stability_path` of the initial Robject with class [`PLNnetworkfamily`]
+#' @return the list of subsamples. The estimated probabilities of selection of the edges are stored in the fields `stability_path` of the initial Robject with class [`Networkfamily`]
 #' @examples
 #' data(trichoptera)
 #' trichoptera <- prepare_data(trichoptera$Abundance, trichoptera$Covariate)
@@ -112,7 +132,8 @@ coefficient_path <- function(Robject, precision = TRUE, corr = TRUE) {
 #' }
 #' @export
 stability_selection <- function(Robject, subsamples = NULL, control = PLNnetwork_param(), force = FALSE) {
-  stopifnot(isPLNnetworkfamily(Robject))
+  stopifnot(isNetworkfamily(Robject))
+  if (inherits(Robject, "ZIPLNnetworkfamily")) control <- ZIPLNnetwork_param()
   if (force || anyNA(Robject$stability)) {
     Robject$stability_selection(subsamples, control)
   } else {
@@ -120,8 +141,6 @@ stability_selection <- function(Robject, subsamples = NULL, control = PLNnetwork
   }
 }
 
-
-
 #' Extract edge selection frequency in bootstrap subsamples
 #'
 #' @description Extracts edge selection frequency in networks reconstructed from bootstrap subsamples
@@ -162,7 +181,7 @@ extract_probs <- function(Robject, penalty = NULL, index = NULL,
                           crit = c("StARS", "BIC", "EBIC"),
                           format = c("matrix", "vector"),
                           tol = 1e-5) {
-  stopifnot(isPLNnetworkfamily(Robject))
+  stopifnot(isNetworkfamily(Robject))
   ## Check if stability selection has been performed
   stab_path <- Robject$stability_path
   if (is.null(stab_path)) {
