@@ -33,25 +33,12 @@ Rcpp::List nlopt_optimize_spherical(
     metadata.map<M_ID>(parameters.data()) = init_M;
     metadata.map<S_ID>(parameters.data()) = init_S;
 
-    auto optimizer = new_nlopt_optimizer(config, parameters.size());
-    if(config.containsElementNamed("xtol_abs")) {
-        SEXP value = config["xtol_abs"];
-        if(Rcpp::is<double>(value)) {
-            set_uniform_xtol_abs(optimizer.get(), Rcpp::as<double>(value));
-        } else {
-            auto per_param_list = Rcpp::as<Rcpp::List>(value);
-            auto packed = std::vector<double>(metadata.packed_size);
-            set_from_r_sexp(metadata.map<B_ID>(packed.data()), per_param_list["B"]);
-            set_from_r_sexp(metadata.map<M_ID>(packed.data()), per_param_list["M"]);
-            set_from_r_sexp(metadata.map<S_ID>(packed.data()), per_param_list["S"]);
-            set_per_value_xtol_abs(optimizer.get(), packed);
-        }
-    }
-
-    const double w_bar = accu(w);
-
     // Optimize
-    auto objective_and_grad = [&metadata, &O, &X, &Y, &w, &w_bar](const double * params, double * grad) -> double {
+    auto optimizer = new_nlopt_optimizer(config, parameters.size());
+    const double w_bar = accu(w);
+    std::vector<double> objective_vec ;
+
+    auto objective_and_grad = [&metadata, &O, &X, &Y, &w, &w_bar, &objective_vec](const double * params, double * grad) -> double {
         const arma::mat B = metadata.map<B_ID>(params);
         const arma::mat M = metadata.map<M_ID>(params);
         const arma::mat S = metadata.map<S_ID>(params);
@@ -65,7 +52,9 @@ Rcpp::List nlopt_optimize_spherical(
 
         metadata.map<B_ID>(grad) = (X.each_col() % w).t() * (A - Y);
         metadata.map<M_ID>(grad) = diagmat(w) * (M / sigma2 + A - Y);
-        metadata.map<S_ID>(grad) = diagmat(w) * (S / sigma2 + S % A - pow(S, -1));
+        metadata.map<S_ID>(grad) = diagmat(w) * (S / sigma2 + S % A - pow(S, -1)) ;
+
+        objective_vec.push_back(objective) ;
 
         return objective;
     };
@@ -101,6 +90,7 @@ Rcpp::List nlopt_optimize_spherical(
         Rcpp::Named("monitoring", Rcpp::List::create(
             Rcpp::Named("status", static_cast<int>(result.status)),
             Rcpp::Named("backend", "nlopt"),
+            Rcpp::Named("objective", objective_vec),
             Rcpp::Named("iterations", result.nb_iterations)
         ))
       );
@@ -132,22 +122,12 @@ Rcpp::List nlopt_optimize_vestep_spherical(
     metadata.map<M_ID>(parameters.data()) = init_M;
     metadata.map<S_ID>(parameters.data()) = init_S;
 
-    auto optimizer = new_nlopt_optimizer(config, parameters.size());
-    if(config.containsElementNamed("xtol_abs")) {
-        SEXP value = config["xtol_abs"];
-        if(Rcpp::is<double>(value)) {
-            set_uniform_xtol_abs(optimizer.get(), Rcpp::as<double>(value));
-        } else {
-            auto per_param_list = Rcpp::as<Rcpp::List>(value);
-            auto packed = std::vector<double>(metadata.packed_size);
-            set_from_r_sexp(metadata.map<M_ID>(packed.data()), per_param_list["M"]);
-            set_from_r_sexp(metadata.map<S_ID>(packed.data()), per_param_list["S"]);
-            set_per_value_xtol_abs(optimizer.get(), packed);
-        }
-    }
 
     // Optimize
-    auto objective_and_grad = [&metadata, &O, &X, &Y, &w, &B, &Omega](const double * params, double * grad) -> double {
+    auto optimizer = new_nlopt_optimizer(config, parameters.size());
+    std::vector<double> objective_vec ;
+
+    auto objective_and_grad = [&metadata, &O, &X, &Y, &w, &B, &Omega, &objective_vec](const double * params, double * grad) -> double {
         const arma::mat M = metadata.map<M_ID>(params);
         const arma::mat S = metadata.map<S_ID>(params);
 
@@ -161,6 +141,8 @@ Rcpp::List nlopt_optimize_vestep_spherical(
         metadata.map<M_ID>(grad) = diagmat(w) * (M / omega2 + A - Y);
         metadata.map<S_ID>(grad) = diagmat(w) * (S / omega2 + S % A - pow(S, -1));
 
+        objective_vec.push_back(objective) ;
+
         return objective;
     };
     OptimizerResult result = minimize_objective_on_parameters(optimizer.get(), objective_and_grad, parameters);
@@ -184,6 +166,7 @@ Rcpp::List nlopt_optimize_vestep_spherical(
         Rcpp::Named("monitoring", Rcpp::List::create(
             Rcpp::Named("status", static_cast<int>(result.status)),
             Rcpp::Named("backend", "nlopt"),
+            Rcpp::Named("objective", objective_vec),
             Rcpp::Named("iterations", result.nb_iterations)
         ))
     );
